==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectProbe.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectprobe_h
#define objectprobe_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_probe_enumeration_seen_no,
  adms_probe_enumeration_seen_yes
} e_probe_seen;
win32_interface char* adms_probe_tostring_seen_impl (p_admsttransform myadmsttransform,e_probe_seen e);
win32_interface e_probe_seen adms_probe_fromstring_seen_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_probe_enumeration_grounded_no,
  adms_probe_enumeration_grounded_yes
} e_probe_grounded;
win32_interface char* adms_probe_tostring_grounded_impl (p_admsttransform myadmsttransform,e_probe_grounded e);
win32_interface e_probe_grounded adms_probe_fromstring_grounded_impl (p_admsttransform myadmsttransform,char*token);
struct s_probe {
  t_subexpression _subexpression;
  p_module _module;
  int _module_isdefault : 1;
  p_branch _branch;
  int _branch_isdefault : 1;
  p_nature _nature;
  int _nature_isdefault : 1;
  e_probe_seen _seen;
  int _seen_isdefault : 1;
  p_discipline _discipline;
  int _discipline_isdefault : 1;
  e_probe_grounded _grounded;
  int _grounded_isdefault : 1;
  p_source _source;
  int _source_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectBranch.h>
#include <admsObject/objectNature.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectSource.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_probe_getuid (p_probe myprobe);
win32_interface gboolean adms_probe_cmp (p_probe myprobe,p_probe refprobe);
win32_interface p_probe adms_probe_new_1 (p_module mymodule,p_branch mybranch,p_nature mynature);
#define adms_probe_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_probe_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_probe_new_impl (p_adms arguments[]);
win32_interface p_probe adms_probe_impl (void* member);
#define adms_probe(member) ((p_probe) (member))
#define adms_probe_new adms_probe_new_1
#define adms_probe_isdefault_module(probe) (adms_probe(probe)->_module_isdefault)
#define adms_probe_valueof_module(probe) (adms_probe(probe)->_module)
#define adms_probe_isdefault_branch(probe) (adms_probe(probe)->_branch_isdefault)
#define adms_probe_valueof_branch(probe) (adms_probe(probe)->_branch)
#define adms_probe_isdefault_nature(probe) (adms_probe(probe)->_nature_isdefault)
#define adms_probe_valueof_nature(probe) (adms_probe(probe)->_nature)
#define adms_probe_isdefault_seen(probe) (adms_probe(probe)->_seen_isdefault)
#define adms_probe_valueof_seen(probe) (adms_probe(probe)->_seen)
#define adms_probe_isdefault_discipline(probe) (adms_probe(probe)->_discipline_isdefault)
#define adms_probe_valueof_discipline(probe) (adms_probe(probe)->_discipline)
#define adms_probe_isdefault_grounded(probe) (adms_probe(probe)->_grounded_isdefault)
#define adms_probe_valueof_grounded(probe) (adms_probe(probe)->_grounded)
#define adms_probe_isdefault_source(probe) (adms_probe(probe)->_source_isdefault)
#define adms_probe_valueof_source(probe) (adms_probe(probe)->_source)
#define adms_probe_valueof_subexpression(probe) ((p_subexpression)probe)
#define adms_probe_valueof_math(probe) ((p_math)probe)
#define adms_probe_valueof_adms(probe) ((p_adms)probe)
#define adms_probe_valueto_module(a,b) ((p_probe)a)->_module=(b)
win32_interface void adms_probe_valueto_module_impl (p_probe myprobe,p_module _module);
#define adms_probe_valueto_branch(a,b) ((p_probe)a)->_branch=(b)
win32_interface void adms_probe_valueto_branch_impl (p_probe myprobe,p_branch _branch);
#define adms_probe_valueto_nature(a,b) ((p_probe)a)->_nature=(b)
win32_interface void adms_probe_valueto_nature_impl (p_probe myprobe,p_nature _nature);
#define adms_probe_valueto_seen(a,b) ((p_probe)a)->_seen=(b)
win32_interface void adms_probe_valueto_seen_impl (p_probe myprobe,e_probe_seen _seen);
#define adms_probe_valueto_discipline(a,b) ((p_probe)a)->_discipline=(b)
win32_interface void adms_probe_valueto_discipline_impl (p_probe myprobe,p_discipline _discipline);
#define adms_probe_valueto_grounded(a,b) ((p_probe)a)->_grounded=(b)
win32_interface void adms_probe_valueto_grounded_impl (p_probe myprobe,e_probe_grounded _grounded);
#define adms_probe_valueto_source(a,b) ((p_probe)a)->_source=(b)
win32_interface void adms_probe_valueto_source_impl (p_probe myprobe,p_source _source);
#endif /* objectprobe_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectProbe.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectprobe_h
#define objectprobe_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_probe_enumeration_seen_no,
  adms_probe_enumeration_seen_yes
} e_probe_seen;
win32_interface char* adms_probe_tostring_seen_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_probe_seen adms_probe_fromstring_seen_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_probe_enumeration_grounded_no,
  adms_probe_enumeration_grounded_yes
} e_probe_grounded;
win32_interface char* adms_probe_tostring_grounded_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_probe_grounded adms_probe_fromstring_grounded_impl (p_admsttransform myadmsttransform,char*token);
struct s_probe {
  t_subexpression _subexpression;
  p_module _module;
  int _module_isdefault : 1;
  p_branch _branch;
  int _branch_isdefault : 1;
  p_nature _nature;
  int _nature_isdefault : 1;
  p_enumeration _seen;
  int _seen_isdefault : 1;
  p_discipline _discipline;
  int _discipline_isdefault : 1;
  p_enumeration _grounded;
  int _grounded_isdefault : 1;
  p_source _source;
  int _source_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectBranch.h>
#include <admsObject/objectNature.h>
#include <admsObject/objectEnumeration.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectSource.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_probe_uid (p_probe myprobe);
win32_interface int adms_probe_cmp (p_probe myprobe,p_probe refprobe);
win32_interface p_probe adms_probe_new(p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_adms adms_probe_new_impl (p_adms arguments[]);
#define adms_probe(member) ((p_probe) (member))
#define adms_probe_isdefault_module(probe) (adms_probe(probe)->_module_isdefault)
#define adms_probe_valueof_module(probe) (adms_probe(probe)->_module)
#define adms_probe_isdefault_branch(probe) (adms_probe(probe)->_branch_isdefault)
#define adms_probe_valueof_branch(probe) (adms_probe(probe)->_branch)
#define adms_probe_isdefault_nature(probe) (adms_probe(probe)->_nature_isdefault)
#define adms_probe_valueof_nature(probe) (adms_probe(probe)->_nature)
#define adms_probe_isdefault_seen(probe) (adms_probe(probe)->_seen_isdefault)
#define adms_probe_valueof_seen(probe) (adms_probe(probe)->_seen)
#define adms_probe_isdefault_discipline(probe) (adms_probe(probe)->_discipline_isdefault)
#define adms_probe_valueof_discipline(probe) (adms_probe(probe)->_discipline)
#define adms_probe_isdefault_grounded(probe) (adms_probe(probe)->_grounded_isdefault)
#define adms_probe_valueof_grounded(probe) (adms_probe(probe)->_grounded)
#define adms_probe_isdefault_source(probe) (adms_probe(probe)->_source_isdefault)
#define adms_probe_valueof_source(probe) (adms_probe(probe)->_source)
#define adms_probe_valueof_subexpression(probe) ((p_subexpression)probe)
#define adms_probe_valueof_math(probe) ((p_math)probe)
#define adms_probe_valueof_adms(probe) ((p_adms)probe)
win32_interface inline void adms_probe_valueto_module (p_probe myprobe,p_module _module);
win32_interface inline void adms_probe_valueto_branch (p_probe myprobe,p_branch _branch);
win32_interface inline void adms_probe_valueto_nature (p_probe myprobe,p_nature _nature);
win32_interface inline void adms_probe_valueto_seen (p_probe myprobe,p_enumeration _seen);
win32_interface inline void adms_probe_valueto_discipline (p_probe myprobe,p_discipline _discipline);
win32_interface inline void adms_probe_valueto_grounded (p_probe myprobe,p_enumeration _grounded);
win32_interface inline void adms_probe_valueto_source (p_probe myprobe,p_source _source);
win32_interface inline void adms_probe_free(p_probe myprobe);
#endif /* objectprobe_h */
